@@ -21,11 +21,18 @@ BUILD_COMMITS_NEW = "NEW"
 
 def get_api_url(app, repo_config, url):
     base_url = repo_config.get("github_api_base",
-            app.config["GITHUB_API_BASE"])
+                               app.config["GITHUB_API_BASE"])
 
     return base_url + url
 
 
+def get_api_response(app, repo_config, url):
+    url = get_api_url(app, repo_config, url).format(
+        repo_name=repo_config.get('github_repo'))
+    s = get_session_for_repo(app, repo_config)
+    return s.get(url)
+
+
 def get_repo_name(pull_request, key):
     return pull_request[key]["repo"]["full_name"]
 
@@ -41,18 +48,18 @@ def get_session_for_repo(app, repo_config):
     if session is None:
         session = requests.Session()
         session.verify = repo_config.get("github_verify",
-            app.config["GITHUB_VERIFY"])
+                                         app.config["GITHUB_VERIFY"])
 
         token = repo_config.get("github_token",
-            app.config.get("GITHUB_TOKEN"))
+                                app.config.get("GITHUB_TOKEN"))
 
         if token:
             session.headers = {"Authorization": "token " + token}
         else:
             user = repo_config.get("github_user",
-                app.config.get("GITHUB_USER"))
+                                   app.config.get("GITHUB_USER"))
             password = repo_config.get("github_password",
-                app.config.get("GITHUB_PASSWORD"))
+                                       app.config.get("GITHUB_PASSWORD"))
             session.auth = (user, password)
     return session
 
@@ -100,7 +107,7 @@ def get_commits(app, repo_config, pull_request):
 
         if build_commits == BUILD_COMMITS_NEW:
             commits = [sha for sha in commits if not
-                has_status(app, repo_config, base_repo_name, sha)]
+                       has_status(app, repo_config, base_repo_name, sha)]
 
         return head_repo_name, commits
     elif build_commits == BUILD_COMMITS_LAST:
@@ -130,15 +137,29 @@ def update_status(app, repo_config, repo_name, sha, state, desc,
     s.post(url, data=json.dumps(params), headers=headers)
 
 
-def has_status(app, repo_config, repo_name, sha):
+def get_status(app, repo_config, repo_name, sha):
+    """Gets the status of a commit.
+
+    .. note::
+        ``repo_name`` might not ever be anything other than
+        ``repo_config['github_repo']``.
+
+    :param app: Flask app for leeroy
+    :param repo_config: configuration for the repo
+    :param repo_name: The name of the owner/repo
+    :param sha: SHA for the status we are looking for
+    :return: returns json response of status
+    """
     url = get_api_url(app, repo_config, github_status_url).format(
-        repo_name=repo_name,
-        sha=sha)
-
+        repo_name=repo_name, sha=sha)
     logging.debug("Getting status for %s %s", repo_name, sha)
-
     s = get_session_for_repo(app, repo_config)
     response = s.get(url)
+    return response
+
+
+def has_status(app, repo_config, repo_name, sha):
+    response = get_status(app, repo_config, repo_name, sha)
 
     # The GitHub commit status API returns a JSON list, so `len()` checks
     # whether any statuses are set for the commit.
@@ -148,9 +169,9 @@ def has_status(app, repo_config, repo_name, sha):
 def register_github_hooks(app):
     with app.app_context():
         github_endpoint = "http://%s%s" % (
-                app.config.get("GITHUB_NOTIFICATION_SERVER_NAME",
-                               app.config["SERVER_NAME"]),
-                url_for("base.github_notification", _external=False))
+            app.config.get("GITHUB_NOTIFICATION_SERVER_NAME",
+                           app.config["SERVER_NAME"]),
+            url_for("base.github_notification", _external=False))
 
     for repo_config in app.config["REPOSITORIES"]:
         repo_name = repo_config["github_repo"]
@@ -180,7 +201,7 @@ def register_github_hooks(app):
             params = {"name": "web",
                       "config": {"url": github_endpoint,
                                  "content_type": "json"},
-                       "events": ["pull_request"]}
+                      "events": ["pull_request"]}
             headers = {"Content-Type": "application/json"}
 
             response = s.post(url, data=json.dumps(params), headers=headers)
@@ -191,3 +212,27 @@ def register_github_hooks(app):
             else:
                 logging.error("Unable to register github hook for %s: %s",
                               repo_name, response.status_code)
+
+
+def get_pull_request(app, repo_config, pull_request):
+    """Data for a given pull request.
+
+    :param app: Flask app
+    :param repo_config: dict with ``github_repo`` key
+    :param pull_request: the pull request number
+    """
+    response = get_api_response(
+        app, repo_config, "/repos/{{repo_name}}/pulls/{}".format(pull_request))
+    return response.json
+
+
+def get_pull_requests(app, repo_config):
+    """Last 30 pull requests from a repository.
+
+    :param app: Flask app
+    :param repo_config: dict with ``github_repo`` key
+
+    :returns: id for a pull request
+    """
+    response = get_api_response(app, repo_config, "/repos/{repo_name}/pulls")
+    return (item for item in response.json)
